@@ -142,7 +142,13 @@ def show_img_predict():
 
 
 
-show_img_predict()
+net = MultiLayerNet()
+net.load_model("./idol_result/train_weight_2021-04-19 033523.npz")
+for k, v in net.params.items():
+    print(k, v.shape)
+
+print(net.layers)
+# show_img_predict()
 
 # show_loss()
 # show_acc()
