@@ -55,11 +55,11 @@ def show_img_by_array(img_array):
 
 def make_net1():
     net = MultiLayerNet(is_use_dropout=False)
-    net.add_layer(Layer.Conv2D(16, (3, 3), pad=1, input_size=(1, 128, 128)), initializer=Initializer.He())
+    net.add_layer(Layer.Conv2D(16, (4, 4), pad=1, input_size=(1, 128, 128)), initializer=Initializer.He())
     net.add_layer(Layer.BatchNormalization())
     net.add_layer(Layer.Relu())
     net.add_layer(Layer.Pooling(pool_h=2, pool_w=2, stride=2))
-    net.add_layer(Layer.Conv2D(32, (3, 3), pad=1, initializer=Initializer.He()))
+    net.add_layer(Layer.Conv2D(32, (4, 4), pad=1, initializer=Initializer.He()))
     net.add_layer(Layer.BatchNormalization())
     net.add_layer(Layer.Relu())
     net.add_layer(Layer.Pooling(pool_h=2, pool_w=2, stride=2))
@@ -178,7 +178,7 @@ def shuffle_dataset(x, t):
 
 print("Loading Dataset..")
 
-load_data = np2.load("./idol_images_rgb_128_v2.npz", allow_pickle=True)
+load_data = np2.load("./idol_images_gray_128_v2.npz", allow_pickle=True)
 x_train = load_data["x_train"]
 
 t_train = load_data["t_train"].astype(np.int64)
@@ -191,16 +191,18 @@ x_test, t_test = shuffle_dataset(x_test, t_test)
 
 
 
+
+
 x_train = x_train / 255
 x_test = x_test / 255
 
 
 def train_model():
-    net = make_net3()
+    net = make_net1()
 
     for k, v in net.params.items():
         print(k, v.shape)
-
+    print(net.layers)
     print(net.hiddenSizeList)
 
     result = net.train(
