@@ -153,8 +153,10 @@ class MultiLayerNet:
 
             conv_output_size = (
                 layer.filter_num, int((input_size[1] - layer.filter_size[0] + 2 * layer.pad) / layer.stride + 1),
-                int((input_size[2] - layer.filter_size[1] + 2 * layer.pad) / layer.stride + 1))
+            int((input_size[2] - layer.filter_size[1] + 2 * layer.pad) / layer.stride + 1))
             #
+            print(conv_output_size, "!!!!!!")
+
             self.hiddenSizeList.append(conv_output_size)
 
             # print("input", self.hiddenSizeList)
@@ -201,6 +203,8 @@ class MultiLayerNet:
 
             self.layers[f"Pooling{layer_len}"] = layer
 
+        elif isinstance(layer, Layer.Dropout):
+            self.layers[f"Dropout{layer_len}"] = Layer.Dropout(layer.dropout_ratio)
 
         elif isinstance(layer, Layer.Relu):
 
