@@ -1,6 +1,6 @@
 # %%
 
-import numpy as np
+from jjy.framework.cuda import xp as np
 
 
 # %%
